@@ -20,6 +20,7 @@
 #include <nmofono/wwan/modem.h>
 
 #include <ofono/dbus.h>
+#include <QDebug>
 
 #define slots
 #include <qofono-qt5/qofonomodem.h>
@@ -52,7 +53,7 @@ static Modem::ModemStatus str2status(const QString& str)
     if (str == "roaming")
         return Modem::ModemStatus::roaming;
 
-    qWarning() << __PRETTY_FUNCTION__ << ": Unknown status" << str;
+    qWarning() << ": Unknown status" << str;
     return Modem::ModemStatus::unknown;
 }
 
@@ -73,7 +74,7 @@ static Modem::Bearer str2technology(const QString& str)
     if (str == "lte")
         return Modem::Bearer::lte;
 
-    qWarning() << __PRETTY_FUNCTION__  << ": Unknown techonology" << str;
+    qWarning() << "Unknown technology" << str;
     return Modem::Bearer::notAvailable;
 }
 }
@@ -96,6 +97,12 @@ public:
     bool m_requiredPinSet = false;
     bool m_retriesSet = false;
 
+    QString m_serial;
+    bool m_serialSet = false;
+    bool m_presentSet = false;
+    bool m_present = false;
+    bool m_readyFired = false;
+
     QString m_operatorName;
     Modem::ModemStatus m_status;
     int8_t m_strength;
@@ -108,6 +115,8 @@ public:
 
     QSet<QString> m_interfaces;
 
+    Sim::Ptr m_sim;
+
     shared_ptr<QOfonoConnectionManager> m_connectionManager;
     shared_ptr<QOfonoNetworkRegistration> m_networkRegistration;
     shared_ptr<QOfonoSimManager> m_simManager;
@@ -125,6 +134,9 @@ public:
         connect(m_ofonoModem.get(), &QOfonoModem::interfacesChanged, this, &Private::interfacesChanged);
         interfacesChanged(m_ofonoModem->interfaces());
 
+        connect(m_ofonoModem.get(), &QOfonoModem::serialChanged, this, &Private::serialChanged);
+        serialChanged(m_ofonoModem->serial());
+
         /// @todo hook up with system-settings to allow changing the identifier.
         ///       for now just provide the defaults
         auto path = m_ofonoModem->modemPath();
@@ -151,9 +163,46 @@ public Q_SLOTS:
 
         if (p.isReadyToUnlock() && m_shouldTriggerUnlock)
         {
+
+            qDebug() << "SIM ready to unlock:" << p.simIdentifier();
             m_shouldTriggerUnlock = false;
             Q_EMIT p.readyToUnlock(p.name());
         }
+
+        if (m_serialSet && !m_readyFired)
+        {
+            if (!m_simManager)
+            {
+                return;
+            }
+
+            if (!m_sim)
+            {
+                if (!m_presentSet)
+                {
+                    return;
+                }
+            }
+
+            m_readyFired = true;
+            Q_EMIT p.ready();
+        }
+    }
+
+    void serialChanged(const QString &value) {
+        if (m_serial == value)
+        {
+            return;
+        }
+        if (m_serialSet)
+        {
+            qWarning() << "Unexpected update on SERIAL: " << m_serial << ", " << value;
+        }
+
+        m_serial = value;
+        m_serialSet = true;
+
+        update();
     }
 
     void connectionManagerChanged(shared_ptr<QOfonoConnectionManager> conmgr)
@@ -233,11 +282,22 @@ public Q_SLOTS:
             connect(m_simManager.get(),
                     &QOfonoSimManager::resetPinComplete, this,
                     &Private::resetPinComplete);
+
+            connect(m_simManager.get(),
+                    &QOfonoSimManager::presenceChanged, this,
+                    &Private::presentChanged);
         }
 
         update();
     }
 
+    void presentChanged()
+    {
+        m_presentSet = true;
+        m_present = m_simManager->present();
+        update();
+    }
+
     void update()
     {
         setOnline(m_ofonoModem->online());
@@ -661,6 +721,12 @@ Modem::index() const
 
 QString
 Modem::name() const
+{
+    return ofonoPath();
+}
+
+QString
+Modem::ofonoPath() const
 {
     return d->m_ofonoModem->modemPath();
 }
@@ -723,10 +789,36 @@ Modem::isReadyToUnlock() const
 void
 Modem::notifyWhenReadyToUnlock()
 {
+    qDebug() << "Notify when ready to unlock" << simIdentifier();
     d->m_shouldTriggerUnlock = true;
 }
+
+Sim::Ptr Modem::sim() const
+{
+    return d->m_sim;
 }
 
+void
+Modem::setSim(Sim::Ptr sim)
+{
+    if (d->m_sim == sim)
+    {
+        return;
+    }
+    d->m_sim = sim;
+    Q_EMIT simUpdated();
+    d->update();
+}
+
+QString
+Modem::serial() const
+{
+    return d->m_serial;
+}
+
+
+
+}
 }
 
 #include "modem.moc"
